from neuromeka.proto import *
from neuromeka.common import *
from neuromeka.enums import *

import grpc
import time

ETHERCAT_PORT = 20000


class EtherCAT:
    def __init__(self, ip_addr):
        # initialize RPC
        ecat_channel = grpc.insecure_channel("{}:{}".format(ip_addr, ETHERCAT_PORT))
        ecat_stub = EtherCATStub(ecat_channel)

        self.__ethercat_stub = ecat_stub

    
    ###### EtherCAT Communication Task gRPC protocol
    # @Utils.exception_handler
    def get_master_status(self):
        """
        Master status
            status -> int
        """
        status = self.__ethercat_stub.GetMasterStatus(common_msgs.Empty()).status
        if status == 1:
            return "INIT"
        elif status == 2:
            return "PRE-OP"
        elif status == 4:
            return "SAFE-OP"
        elif status == 8:
            return "OP"
        else:
            return "None"

    @Utils.exception_handler
    def get_slave_status(self):
        """
        Slave status

        """
        status = (self.__ethercat_stub.GetSlaveStatus(common_msgs.Empty()).status)
        slave_status = []
        for stat in status:
            if stat == 1:
                slave_status.append("INIT")
            elif stat == 2:
                slave_status.append("PRE-OP")
            elif stat == 4:
                slave_status.append("SAFE-OP")
            elif stat == 8:
                slave_status.append("OP")
            else:
                slave_status.append("None")
        return slave_status

    @Utils.exception_handler
    def get_txdomain_status(self):
        """
        PDO Tx Domain status
        """
        status = self.__ethercat_stub.GetTxDomainStatus(common_msgs.Empty()).status
        if status == 0:
            return "ZERO"
        elif status == 1:
            return "INCOMPLETE"
        elif status == 2:
            return "COMPLETE"
        else:
            return "None"

    @Utils.exception_handler
    def get_rxdomain_status(self):
        """
        PDO Rx Domain status
        """
        status = self.__ethercat_stub.GetRxDomainStatus(common_msgs.Empty()).status
        if status == 0:
            return "ZERO"
        elif status == 1:
            return "INCOMPLETE"
        elif status == 2:
            return "COMPLETE"
        else:
            return "None"

    @Utils.exception_handler
    def is_system_ready(self) -> list:
        """
        System ready state
        """
        return list(self.__ethercat_stub.IsSystemReady(common_msgs.Empty()).ready)

    @Utils.exception_handler
    def is_servo_on(self) -> list:
        """
        Servo on state
        """
        return list(self.__ethercat_stub.IsServoOn(common_msgs.Empty()).servo)

    @Utils.exception_handler
    def get_slave_type_num(self):
        """
        Servo on state
        """
        return self.__ethercat_stub.GetSlaveTypeNum(common_msgs.Empty())

    @Utils.exception_handler
    def reset_overflow_count(self):
        """
        Reset and save overflow count
        """
        return self.__ethercat_stub.ResetOverflowCount(common_msgs.Empty())

    @Utils.exception_handler
    def set_servo(self, servo_idx, on):
        """
        Servo on state
        """
        if on:
            self.__ethercat_stub.SetServoOn(ethercat_msgs.ServoIndex(servoIndex=servo_idx))
        else:
            self.__ethercat_stub.SetServoOff(ethercat_msgs.ServoIndex(servoIndex=servo_idx))

    @Utils.exception_handler
    def get_servo_tx(self, servo_idx):
        """
        Get Servo driver's Tx PDO values
        """
        res = self.__ethercat_stub.GetServoTx(ethercat_msgs.ServoIndex(servoIndex=servo_idx))
        return [EtherCATStatus.status2string(res.statusWord),
                EtherCATStatus.modeop2string(res.modeOpDisp), res.actualPosition, res.actualVelocity, res.actualTorque]

    @Utils.exception_handler
    def get_servo_tx_raw(self, servo_idx):
        """
        Get Servo driver's Tx PDO values
        """
        return self.__ethercat_stub.GetServoTx(ethercat_msgs.ServoIndex(servoIndex=servo_idx))

    @Utils.exception_handler
    def get_servo_tx_keba(self, servo_idx):
        """
        Get Servo (Keba) driver's Tx PDO values
        """
        res = self.__ethercat_stub.GetServoTxKeba(ethercat_msgs.ServoIndex(servoIndex=servo_idx))
        res1 = [EtherCATStatus.status2string(res.statusWord), res.actualPosition, res.actualVelocity]
        res2 = [EtherCATStatus.status2string(res.statusWord2), res.actualPosition2, res.actualVelocity2]
        res3 = [EtherCATStatus.status2string(res.statusWord3), res.actualPosition3, res.actualVelocity3]
        return [res1, res2, res3]

    @Utils.exception_handler
    def get_servo_rx_keba(self, servo_idx):
        """
        Get Servo (Keba) driver's Rx PDO values
        """
        res = self.__ethercat_stub.GetServoRxKeba(ethercat_msgs.ServoIndex(servoIndex=servo_idx))
        res1 = [res.controlWord, res.targetPosition, res.targetTorque]
        res2 = [res.controlWord2, res.targetPosition2, res.targetTorque2]
        res3 = [res.controlWord3, res.targetPosition3, res.targetTorque3]
        return [res1, res2, res3]

    @Utils.exception_handler
    def get_servo_rx(self, servo_idx):
        """
        Get Servo driver's Rx PDO values
        """
        res = self.__ethercat_stub.GetServoRx(ethercat_msgs.ServoIndex(servoIndex=servo_idx))
        return [res.controlWord, res.modeOp, res.targetPosition, res.targetVelocity, res.targetTorque]

    @Utils.exception_handler
    def set_servo_rx(self, servo_idx, control_word, mode_op, target_pos, target_vel, target_tor):
        """
        Set Servo driver's Rx PDO values
        """
        print(servo_idx, control_word, mode_op, target_pos, target_vel, target_tor)
        servo_rx = ServoRx(controlWord=control_word, modeOp=mode_op, targetPosition=target_pos, targetVelocity=target_vel, targetTorque=target_tor)
        return self.__ethercat_stub.SetServoRx(ethercat_msgs.ServoRxIndex(servoIndex=servo_idx, rx=servo_rx))

    @Utils.exception_handler
    def set_servo_rx_keba(self, servo_idx, rx1, rx2, rx3):
        """
        Set Servo (Keba) driver's Rx PDO values
        """
        control_word = rx1[0]
        control_word2 = rx2[0]
        control_word3 = rx3[0]

        target_pos = rx1[1]
        target_pos2 = rx2[1]
        target_pos3 = rx3[1]

        target_tor = rx1[2]
        target_tor2 = rx2[2]
        target_tor3 = rx3[2]
        servo_rx = ServoRxKeba(controlWord=control_word, controlWord2=control_word2, controlWord3=control_word3,
                               targetPosition=target_pos, targetPosition2=target_pos2, targetPosition3=target_pos3,
                               targetTorque=target_tor, targetTorque2=target_tor2, targetTorque3=target_tor3)
        return self.__ethercat_stub.SetServoRx(ethercat_msgs.ServoRxIndexKeba(servoIndex=servo_idx, rx=servo_rx))

    @Utils.exception_handler
    def get_servo_temperature(self, servo_idx):
        """
        Get Servo SDO temperatures
        """
        return self.__ethercat_stub.GetServoTemperature(ethercat_msgs.ServoIndex(servoIndex=servo_idx)).temperature

    @Utils.exception_handler
    def get_servo_errorcode(self, servo_idx):
        """
        Get Servo SDO error code
        """
        return self.__ethercat_stub.GetServoErrorCode(ethercat_msgs.ServoIndex(servoIndex=servo_idx)).errorCode

    @Utils.exception_handler
    def reset_servo(self, servo_idx):
        """
        Reset servo error
        """
        return self.__ethercat_stub.ResetServo(ethercat_msgs.ServoIndex(servoIndex=servo_idx))

    @Utils.exception_handler
    def set_brake(self, ecat_idx, onoff):
        """
        Manual brake by SDO
        """
        return self.__ethercat_stub.SetCOREManualBrake(ethercat_msgs.ServoBrake(ecatIndex=ecat_idx, onoff=onoff))

    @Utils.exception_handler
    def set_endtool_rx(self, endtool_rx):
        """
        Set endtool Rx data
        """
        eqc = endtool_rx["eqc"]
        gripper = endtool_rx["gripper"]
        ft_param = endtool_rx["ft_param"]
        led_mode = endtool_rx["led_mode"]
        led_g = endtool_rx["led_g"]
        led_r = endtool_rx["led_r"]
        led_b = endtool_rx["led_b"]
        return self.__ethercat_stub.SetEndtoolRx(EndtoolRx(eqc=eqc, gripper=gripper, ft_param=ft_param, led_mode=led_mode, led_g=led_g, led_r=led_r, led_b=led_b))

    @Utils.exception_handler
    def get_endtool_rx(self):
        """
        Get endtool Rx data
        """
        endtool_rx = {}
        data = self.__ethercat_stub.GetEndtoolRx(common_msgs.Empty())
        endtool_rx["eqc"] = data.eqc
        endtool_rx["gripper"] = data.gripper
        endtool_rx["ft_param"] = data.ft_param
        endtool_rx["led_mode"] = data.led_mode
        endtool_rx["led_g"] = data.led_g
        endtool_rx["led_r"] = data.led_r
        endtool_rx["led_b"] = data.led_b
        return endtool_rx

    @Utils.exception_handler
    def get_endtool_tx(self):
        """
        Get endtool Tx data
        """
        endtool_tx = {}
        data = self.__ethercat_stub.GetEndtoolTx(common_msgs.Empty())
        endtool_tx["status"] = data.status
        endtool_tx["button"] = data.button
        endtool_tx["ft_sensor"] = data.ft_sensor
        endtool_tx["ft_state"] = data.ft_state
        endtool_tx["ft_error"] = data.ft_error
        return endtool_tx

    @Utils.exception_handler
    def get_ioboard_tx(self):
        """
        Get ioboard Tx data
        """
        ioboard_tx = {}
        data = self.__ethercat_stub.GetIOBoardTx(common_msgs.Empty())
        ioboard_tx["di5v"] = data.di5v
        ioboard_tx["di24v1"] = data.di24v1
        ioboard_tx["di24v2"] = data.di24v2
        ioboard_tx["ai1"] = data.ai1
        ioboard_tx["ai2"] = data.ai2
        return ioboard_tx

    @Utils.exception_handler
    def get_ioboard_rx(self):
        """
        Get ioboard Rx data
        """
        ioboard_rx = {}
        data = self.__ethercat_stub.GetIOBoardRx(common_msgs.Empty())
        ioboard_rx["do5v"] = data.do5v
        ioboard_rx["do24v1"] = data.do24v1
        ioboard_rx["do24v2"] = data.do24v2
        ioboard_rx["ao1"] = data.ao1
        ioboard_rx["ao2"] = data.ao2
        ioboard_rx["ft_param"] = data.ft_param
        return ioboard_rx

    @Utils.exception_handler
    def set_ioboard_rx(self, ioboard_rx):
        """
        Set ioboard Rx data
        """
        do5v = ioboard_rx["do5v"]
        do24v1 = ioboard_rx["do24v1"]
        do24v2 = ioboard_rx["do24v2"]
        ao1 = ioboard_rx["ao1"]
        ao2 = ioboard_rx["ao2"]
        ft_param = ioboard_rx["ft_param"]
        return self.__ethercat_stub.SetIOBoardRx(
            EndtoolRx(do5v=do5v, do24v1=do24v1, do24v2=do24v2, ao1=ao1, ao2=ao2, ft_param=ft_param))


    @Utils.exception_handler
    def get_di(self, dio_index):
        """
        Get DIO Tx data
        """
        return self.__ethercat_stub.GetDI(ethercat_msgs.DIOIndex(dioIndex=dio_index)).di_list

    @Utils.exception_handler
    def get_do(self, dio_index):
        """
        Set ioboard Rx data
        """
        return self.__ethercat_stub.GetDO(ethercat_msgs.DIOIndex(dioIndex=dio_index)).do_list

    @Utils.exception_handler
    def set_do(self, dio_index, dio):
        """
        Set ioboard Rx data
        """
        return self.__ethercat_stub.SetDO(ethercat_msgs.DIODigitalOutput(dioIndex=dio_index, do_list=dio))


    @Utils.exception_handler
    def set_maxTorque(self, slave_idx, value):
        """
        Set Maximum Torque [ecat idx, torq]
        """
        return self.__ethercat_stub.SetMaxTorqueSDO(ethercat_msgs.ServoParam(slaveIdx=slave_idx, val=value))

    @Utils.exception_handler
    def set_profileVel(self, slave_idx, value):
        """
        Set Profile Velocity [ecat idx, vel]
        """
        return self.__ethercat_stub.SetProfileVelSDO(ethercat_msgs.ServoParam(slaveIdx=slave_idx, val=value))

    @Utils.exception_handler
    def set_profileAcc(self, slave_idx, value):
        """
        Set Profile Acceleration [ecat idx, acc]
        """
        return self.__ethercat_stub.SetProfileAccSDO(ethercat_msgs.ServoParam(slaveIdx=slave_idx, val=value))

    @Utils.exception_handler
    def set_profileDec(self, slave_idx, value):
        """
        Set Profile Deceleration [ecat idx, dec]
        """
        return self.__ethercat_stub.SetProfileDecSDO(ethercat_msgs.ServoParam(slaveIdx=slave_idx, val=value))

    @Utils.exception_handler
    def get_maxTorque(self, slave_idx):
        """
        Get Maximum Torque [ecat idx]
        """
        return self.__ethercat_stub.GetMaxTorqueSDO(ethercat_msgs.EcatIndex(ecatIndex=slave_idx)).val

    @Utils.exception_handler
    def get_profileVel(self, slave_idx):
        """
        Get Profile Velocity [ecat idx]
        """
        return self.__ethercat_stub.GetProfileVelSDO(ethercat_msgs.EcatIndex(ecatIndex=slave_idx)).val

    @Utils.exception_handler
    def get_profileAcc(self, slave_idx):
        """
        Get Profile Acceleration [ecat idx]
        """
        return self.__ethercat_stub.GetProfileAccSDO(ethercat_msgs.EcatIndex(ecatIndex=slave_idx)).val

    @Utils.exception_handler
    def get_profileDec(self, slave_idx):
        """
        Get Profile Deceleration [ecat idx]
        """
        return self.__ethercat_stub.GetProfileDecSDO(ethercat_msgs.EcatIndex(ecatIndex=slave_idx)).val


    def get_robot_zero_count(self, servo_idx):
        """
        Get robot zero count
        """
        return self.__ethercat_stub.GetRobotZeroCount(ethercat_msgs.ServoIndex(servoIndex=servo_idx))

    @Utils.exception_handler
    def set_robot_zero_as_current(self, servo_idx):
        """
        Set robot zero as current
        """
        return self.__ethercat_stub.SetRobotZeroAsCurrent(ethercat_msgs.ServoIndex(servoIndex=servo_idx))


    ## Conty Linear Ext Servo
    @Utils.exception_handler
    def get_axis_data(self,servo_idx):
        """
        Axis Data:
          repeated bool active = 1;
          repeated float pos_mm = 2;
          repeated float vel_mm = 3;

          repeated float despos_mm = 4;
          repeated float desvel_mm = 5;
          repeated float desacc_mm = 6;

          uint32 num_axes = 10;
          OpState op_state = 11;
          TrajState traj_state = 12;
        """
        """
        # enum OpState {
            SYSTEM_OFF = 0;
            SYSTEM_ON = 1;
            VIOLATE = 2;
            RECOVER_HARD = 3;
            RECOVER_SOFT = 4;
            IDLE = 5;
            MOVING = 6;
            }
        # enum TrajState {
            TRAJ_NONE = 0;
            TRAJ_INIT = 1;
            TRAJ_CALC = 2;
            TRAJ_STBY = 3;
            TRAJ_ACC = 4;
            TRAJ_CRZ = 5;
            TRAJ_DEC = 6;
            TRAJ_CANC = 7;
            TRAJ_FIN = 8;
            TRAJ_ERR = 9;
            }
        """
        num_axes = 1 # num_axes ##TO CONFIG
        servo_tx = self.get_servo_tx(servo_idx)  ##TO CONFIG
        servo_rx = self.get_servo_rx(servo_idx)

        #active
        if servo_tx[0] == 'OPERATION_ENABLED':
            active = [True]
        else:
            active = [False]

        convert = 1/7200 # 1rev per 0.5cm  , 1rev per 360000feed ##TO CONFIG

        pos_cnt = servo_tx[2] # actualPos
        pos_mm = [pos_cnt * convert]

        vel_cnt = servo_tx[3] # actualVel
        vel_mm = [vel_cnt * convert]

        despos_cnt = servo_rx[2]
        despos_mm = despos_cnt * convert

        desvel_mm = 0.0 # ethertoolslave -p0 upload -t uint32 0x6081 0  (profiled velocity)
        desacc_mm = 0.0 # ethertoolslave -p0 upload -t uint32 0x6083 0  (profiled velocity)
        # ethertoolslave -p0 upload -t uint32 0x6084 0  (profiled velocity)

        if self.is_servo_on()[servo_idx]:
            op_state = 1 # SYSTEM_ON
            if self.is_system_ready()[servo_idx]:
                op_state = 5 # IDLE
            elif self.is_system_ready()[servo_idx] & servo_rx[2] != 0:
                op_state = 6 # MOVING
        else:
            op_state = 0 # SYSTEM_OFF

        traj_state: TrajState = TrajState.TRAJ_NONE


        # print(f"num_axes = {type(num_axes)}")
        # print(f"active = {type(active)}")
        # print(f"pos_mm = {type(pos_mm)}")
        # print(f"vel_mm = {type(vel_mm)}")
        # print(f"despos_mm = {type(despos_mm)}")
        # print(f"desvel_mm = {type(desvel_mm)}")
        # print(f"desacc_mm = {type(desacc_mm)}")

        # print(f"op_state = {type(op_state)}")
        # print(f"traj_state = {type(traj_state)}")

        axis_data_dict = {
            "active" : active,
            "pos_mm" : pos_mm,
            "vel_mm" : vel_mm,
            "despos_mm" : despos_mm,
            "desvel_mm" : desvel_mm,
            "desacc_mm" : desacc_mm,
            "num_axes" : num_axes,
            "op_state" : op_state,
            "traj_state" : traj_state
        }

        # print('Linear Axis Data: ' + str(axis_data_dict))
        return axis_data_dict

    @Utils.exception_handler
    def move_axis(self,
                  servo_idx,
                  start_mm,
                  target_mm,
                  is_absolute=True,
                  vel_ratio=50,
                  acc_ratio=100,
                  teaching_mode=True):
        """
        start_mm = [mm, mm, mm] -> pos
        target_mm = [mm, mm, mm] -> pos
        vel_mm : int -> vel_ratio
        acc_mm : int -> acc_ratio
        is_absolute : True if target is absolute -> base_type
        """
        # print("Linear Control ====================")
        # print("target_mm ", target_mm)
        # print("is_absolute ", is_absolute)
        # print("vel_ratio ", vel_ratio)
        # print("teaching_mode ", teaching_mode)

        vel = Limits.ExternalMotorSpeedMax * vel_ratio / 100
        acc = vel * acc_ratio / 100

        # servo_tx = self.get_servo_tx(EXT_SERVO_IDX)
        # servo_rx = self.get_servo_rx(EXT_SERVO_IDX)
        convert = 1/7200
        sync_mode=False
        if teaching_mode:
            # curr_pos = servo_tx[2]
            tar_pos_cnt = int(target_mm / convert)

            if sync_mode:
                self.set_servo_rx(servo_idx, 0x1f, 0x01, tar_pos_cnt, 0, 0)
            else:
                self.set_servo_rx(servo_idx, 0x3f,0x01, tar_pos_cnt, 0, 0)
                time.sleep(0.01)
                self.set_servo_rx(servo_idx, 0x2f, 0x01, tar_pos_cnt, 0, 0)

        linear_target = {
            "start_mm" : [float(start_mm)],
            "target_mm" : [float(target_mm)],
            "is_absolute" : is_absolute,
            "vel_ratio" : float(vel_ratio),
            "acc_ratio" : float(acc_ratio),
            "teaching_mode" : [teaching_mode]
        }
        # print(f"linear target : {str(linear_target)}")

        return linear_target


    @Utils.exception_handler
    def stop_motion(self, servo_idx):
        print("StopMotion Frome Ethercat_client")
        self.set_servo_rx(servo_idx, 15, 10, 0, 0, 0)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import control_msgs_pb2 as control__msgs__pb2
import config_msgs_pb2 as config__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='control.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rcontrol.proto\x12\x12Nrmk.IndyFramework\x1a\x12\x63ontrol_msgs.proto\x1a\x11\x63onfig_msgs.proto\x1a\x11\x63ommon_msgs.proto2\xc6-\n\x07\x43ontrol\x12N\n\x0eGetControlInfo\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.ControlInfo\"\x00\x12[\n\x0f\x41\x63tivateIndySDK\x12\".Nrmk.IndyFramework.SDKLicenseInfo\x1a\".Nrmk.IndyFramework.SDKLicenseResp\"\x00\x12\x45\n\x05MoveJ\x12\x1c.Nrmk.IndyFramework.MoveJReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x06MoveJT\x12\x1d.Nrmk.IndyFramework.MoveJTReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12\x45\n\x05MoveL\x12\x1c.Nrmk.IndyFramework.MoveLReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x06MoveLT\x12\x1d.Nrmk.IndyFramework.MoveLTReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12\x45\n\x05MoveC\x12\x1c.Nrmk.IndyFramework.MoveCReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x06MoveCT\x12\x1d.Nrmk.IndyFramework.MoveCTReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x06WaitIO\x12\x1d.Nrmk.IndyFramework.WaitIOReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12K\n\x08WaitTime\x12\x1f.Nrmk.IndyFramework.WaitTimeReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12S\n\x0cWaitProgress\x12#.Nrmk.IndyFramework.WaitProgressReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12K\n\x08WaitTraj\x12\x1f.Nrmk.IndyFramework.WaitTrajReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12O\n\nWaitRadius\x12!.Nrmk.IndyFramework.WaitRadiusReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12M\n\tMoveJCond\x12 .Nrmk.IndyFramework.MoveJCondReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12I\n\nStopMotion\x12\x1b.Nrmk.IndyFramework.StopCat\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12K\n\x0bPauseMotion\x12\x1c.Nrmk.IndyFramework.PauseCat\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12N\n\x11SetDirectTeaching\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12N\n\x11SetSimulationMode\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12S\n\x14SetCustomControlMode\x12\x1b.Nrmk.IndyFramework.IntMode\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12P\n\x14GetCustomControlMode\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.IntMode\"\x00\x12T\n\x17SetFrictionCompensation\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12V\n\x1cGetFrictionCompensationState\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.State\"\x00\x12\x44\n\x07Recover\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12N\n\x11SetManualRecovery\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12O\n\x10MoveRecoverJoint\x12\x1b.Nrmk.IndyFramework.TargetJ\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12O\n\rSearchProgram\x12\x1b.Nrmk.IndyFramework.Program\x1a\x1f.Nrmk.IndyFramework.ProgramInfo\"\x00\x12J\n\x0bPlayProgram\x12\x1b.Nrmk.IndyFramework.Program\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12I\n\x0cPauseProgram\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12J\n\rResumeProgram\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12H\n\x0bStopProgram\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12\x45\n\tSendAlarm\x12\x1b.Nrmk.IndyFramework.Message\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0eSendAnnotation\x12\x1b.Nrmk.IndyFramework.Message\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12\x61\n\x11PlayTuningProgram\x12!.Nrmk.IndyFramework.TuningProgram\x1a\'.Nrmk.IndyFramework.CollisionThresholds\"\x00\x12`\n\x19SetModbusVariableNameList\x12&.Nrmk.IndyFramework.ModbusVariableList\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x13SetVariableNameList\x12\x1b.Nrmk.IndyFramework.AllVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x13GetVariableNameList\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.AllVars\"\x00\x12J\n\x0eSetIntVariable\x12\x1b.Nrmk.IndyFramework.IntVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0eGetIntVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.IntVars\"\x00\x12P\n\x11SetModbusVariable\x12\x1e.Nrmk.IndyFramework.ModbusVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12P\n\x11GetModbusVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.ModbusVars\"\x00\x12L\n\x0fSetBoolVariable\x12\x1c.Nrmk.IndyFramework.BoolVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12L\n\x0fGetBoolVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.BoolVars\"\x00\x12N\n\x10SetFloatVariable\x12\x1d.Nrmk.IndyFramework.FloatVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12N\n\x10GetFloatVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.FloatVars\"\x00\x12L\n\x0fSetJPosVariable\x12\x1c.Nrmk.IndyFramework.JPosVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12L\n\x0fGetJPosVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.JPosVars\"\x00\x12L\n\x0fSetTPosVariable\x12\x1c.Nrmk.IndyFramework.TPosVars\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12L\n\x0fGetTPosVariable\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.TPosVars\"\x00\x12i\n\x11InverseKinematics\x12(.Nrmk.IndyFramework.InverseKinematicsReq\x1a(.Nrmk.IndyFramework.InverseKinematicsRes\"\x00\x12~\n\x18\x43heckAproachRetractValid\x12/.Nrmk.IndyFramework.CheckAproachRetractValidReq\x1a/.Nrmk.IndyFramework.CheckAproachRetractValidRes\"\x00\x12l\n\x12GetPalletPointList\x12).Nrmk.IndyFramework.GetPalletPointListReq\x1a).Nrmk.IndyFramework.GetPalletPointListRes\"\x00\x12u\n\x15\x43\x61lculateRelativePose\x12,.Nrmk.IndyFramework.CalculateRelativePoseReq\x1a,.Nrmk.IndyFramework.CalculateRelativePoseRes\"\x00\x12{\n\x17\x43\x61lculateCurrentPoseRel\x12..Nrmk.IndyFramework.CalculateCurrentPoseRelReq\x1a..Nrmk.IndyFramework.CalculateCurrentPoseRelRes\"\x00\x12G\n\rPingFromConty\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12P\n\x0fGetTeleOpDevice\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.TeleOpDevice\"\x00\x12N\n\x0eGetTeleOpState\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.TeleOpState\"\x00\x12W\n\x13\x43onnectTeleOpDevice\x12 .Nrmk.IndyFramework.TeleOpDevice\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12S\n\x16\x44isConnectTeleOpDevice\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12I\n\x0fReadTeleOpInput\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.TeleP\"\x00\x12N\n\x0bStartTeleOp\x12\x1f.Nrmk.IndyFramework.TeleOpState\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\nStopTeleOp\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12O\n\x0bSetPlayRate\x12 .Nrmk.IndyFramework.TelePlayRate\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12L\n\x0bGetPlayRate\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.TelePlayRate\"\x00\x12R\n\x0fGetTeleFileList\x12\x19.Nrmk.IndyFramework.Empty\x1a\".Nrmk.IndyFramework.TeleOpFileList\"\x00\x12Q\n\x0eSaveTeleMotion\x12\x1f.Nrmk.IndyFramework.TeleFileReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12Q\n\x0eLoadTeleMotion\x12\x1f.Nrmk.IndyFramework.TeleFileReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12S\n\x10\x44\x65leteTeleMotion\x12\x1f.Nrmk.IndyFramework.TeleFileReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12J\n\rEnableTeleKey\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12M\n\tMoveTeleJ\x12 .Nrmk.IndyFramework.MoveTeleJReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12M\n\tMoveTeleL\x12 .Nrmk.IndyFramework.MoveTeleLReq\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12H\n\x06MoveFL\x12\x1d.Nrmk.IndyFramework.MoveFLReq\x1a\x1d.Nrmk.IndyFramework.MoveFLRes\"\x00\x62\x06proto3'
  ,
  dependencies=[control__msgs__pb2.DESCRIPTOR,config__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CONTROL = _descriptor.ServiceDescriptor(
  name='Control',
  full_name='Nrmk.IndyFramework.Control',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=96,
  serialized_end=5926,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetControlInfo',
    full_name='Nrmk.IndyFramework.Control.GetControlInfo',
    index=0,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._CONTROLINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateIndySDK',
    full_name='Nrmk.IndyFramework.Control.ActivateIndySDK',
    index=1,
    containing_service=None,
    input_type=control__msgs__pb2._SDKLICENSEINFO,
    output_type=control__msgs__pb2._SDKLICENSERESP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveJ',
    full_name='Nrmk.IndyFramework.Control.MoveJ',
    index=2,
    containing_service=None,
    input_type=control__msgs__pb2._MOVEJREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveJT',
    full_name='Nrmk.IndyFramework.Control.MoveJT',
    index=3,
    containing_service=None,
    input_type=control__msgs__pb2._MOVEJTREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveL',
    full_name='Nrmk.IndyFramework.Control.MoveL',
    index=4,
    containing_service=None,
    input_type=control__msgs__pb2._MOVELREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveLT',
    full_name='Nrmk.IndyFramework.Control.MoveLT',
    index=5,
    containing_service=None,
    input_type=control__msgs__pb2._MOVELTREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveC',
    full_name='Nrmk.IndyFramework.Control.MoveC',
    index=6,
    containing_service=None,
    input_type=control__msgs__pb2._MOVECREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveCT',
    full_name='Nrmk.IndyFramework.Control.MoveCT',
    index=7,
    containing_service=None,
    input_type=control__msgs__pb2._MOVECTREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitIO',
    full_name='Nrmk.IndyFramework.Control.WaitIO',
    index=8,
    containing_service=None,
    input_type=control__msgs__pb2._WAITIOREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitTime',
    full_name='Nrmk.IndyFramework.Control.WaitTime',
    index=9,
    containing_service=None,
    input_type=control__msgs__pb2._WAITTIMEREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitProgress',
    full_name='Nrmk.IndyFramework.Control.WaitProgress',
    index=10,
    containing_service=None,
    input_type=control__msgs__pb2._WAITPROGRESSREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitTraj',
    full_name='Nrmk.IndyFramework.Control.WaitTraj',
    index=11,
    containing_service=None,
    input_type=control__msgs__pb2._WAITTRAJREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitRadius',
    full_name='Nrmk.IndyFramework.Control.WaitRadius',
    index=12,
    containing_service=None,
    input_type=control__msgs__pb2._WAITRADIUSREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveJCond',
    full_name='Nrmk.IndyFramework.Control.MoveJCond',
    index=13,
    containing_service=None,
    input_type=control__msgs__pb2._MOVEJCONDREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopMotion',
    full_name='Nrmk.IndyFramework.Control.StopMotion',
    index=14,
    containing_service=None,
    input_type=common__msgs__pb2._STOPCAT,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseMotion',
    full_name='Nrmk.IndyFramework.Control.PauseMotion',
    index=15,
    containing_service=None,
    input_type=common__msgs__pb2._PAUSECAT,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDirectTeaching',
    full_name='Nrmk.IndyFramework.Control.SetDirectTeaching',
    index=16,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSimulationMode',
    full_name='Nrmk.IndyFramework.Control.SetSimulationMode',
    index=17,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCustomControlMode',
    full_name='Nrmk.IndyFramework.Control.SetCustomControlMode',
    index=18,
    containing_service=None,
    input_type=common__msgs__pb2._INTMODE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCustomControlMode',
    full_name='Nrmk.IndyFramework.Control.GetCustomControlMode',
    index=19,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._INTMODE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFrictionCompensation',
    full_name='Nrmk.IndyFramework.Control.SetFrictionCompensation',
    index=20,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFrictionCompensationState',
    full_name='Nrmk.IndyFramework.Control.GetFrictionCompensationState',
    index=21,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._STATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Recover',
    full_name='Nrmk.IndyFramework.Control.Recover',
    index=22,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetManualRecovery',
    full_name='Nrmk.IndyFramework.Control.SetManualRecovery',
    index=23,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveRecoverJoint',
    full_name='Nrmk.IndyFramework.Control.MoveRecoverJoint',
    index=24,
    containing_service=None,
    input_type=control__msgs__pb2._TARGETJ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchProgram',
    full_name='Nrmk.IndyFramework.Control.SearchProgram',
    index=25,
    containing_service=None,
    input_type=control__msgs__pb2._PROGRAM,
    output_type=control__msgs__pb2._PROGRAMINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PlayProgram',
    full_name='Nrmk.IndyFramework.Control.PlayProgram',
    index=26,
    containing_service=None,
    input_type=control__msgs__pb2._PROGRAM,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseProgram',
    full_name='Nrmk.IndyFramework.Control.PauseProgram',
    index=27,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeProgram',
    full_name='Nrmk.IndyFramework.Control.ResumeProgram',
    index=28,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopProgram',
    full_name='Nrmk.IndyFramework.Control.StopProgram',
    index=29,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendAlarm',
    full_name='Nrmk.IndyFramework.Control.SendAlarm',
    index=30,
    containing_service=None,
    input_type=common__msgs__pb2._MESSAGE,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendAnnotation',
    full_name='Nrmk.IndyFramework.Control.SendAnnotation',
    index=31,
    containing_service=None,
    input_type=common__msgs__pb2._MESSAGE,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PlayTuningProgram',
    full_name='Nrmk.IndyFramework.Control.PlayTuningProgram',
    index=32,
    containing_service=None,
    input_type=control__msgs__pb2._TUNINGPROGRAM,
    output_type=config__msgs__pb2._COLLISIONTHRESHOLDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetModbusVariableNameList',
    full_name='Nrmk.IndyFramework.Control.SetModbusVariableNameList',
    index=33,
    containing_service=None,
    input_type=control__msgs__pb2._MODBUSVARIABLELIST,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVariableNameList',
    full_name='Nrmk.IndyFramework.Control.SetVariableNameList',
    index=34,
    containing_service=None,
    input_type=control__msgs__pb2._ALLVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVariableNameList',
    full_name='Nrmk.IndyFramework.Control.GetVariableNameList',
    index=35,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._ALLVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetIntVariable',
    full_name='Nrmk.IndyFramework.Control.SetIntVariable',
    index=36,
    containing_service=None,
    input_type=control__msgs__pb2._INTVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIntVariable',
    full_name='Nrmk.IndyFramework.Control.GetIntVariable',
    index=37,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._INTVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetModbusVariable',
    full_name='Nrmk.IndyFramework.Control.SetModbusVariable',
    index=38,
    containing_service=None,
    input_type=control__msgs__pb2._MODBUSVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModbusVariable',
    full_name='Nrmk.IndyFramework.Control.GetModbusVariable',
    index=39,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._MODBUSVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBoolVariable',
    full_name='Nrmk.IndyFramework.Control.SetBoolVariable',
    index=40,
    containing_service=None,
    input_type=control__msgs__pb2._BOOLVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBoolVariable',
    full_name='Nrmk.IndyFramework.Control.GetBoolVariable',
    index=41,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._BOOLVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFloatVariable',
    full_name='Nrmk.IndyFramework.Control.SetFloatVariable',
    index=42,
    containing_service=None,
    input_type=control__msgs__pb2._FLOATVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFloatVariable',
    full_name='Nrmk.IndyFramework.Control.GetFloatVariable',
    index=43,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._FLOATVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetJPosVariable',
    full_name='Nrmk.IndyFramework.Control.SetJPosVariable',
    index=44,
    containing_service=None,
    input_type=control__msgs__pb2._JPOSVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJPosVariable',
    full_name='Nrmk.IndyFramework.Control.GetJPosVariable',
    index=45,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._JPOSVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTPosVariable',
    full_name='Nrmk.IndyFramework.Control.SetTPosVariable',
    index=46,
    containing_service=None,
    input_type=control__msgs__pb2._TPOSVARS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTPosVariable',
    full_name='Nrmk.IndyFramework.Control.GetTPosVariable',
    index=47,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TPOSVARS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InverseKinematics',
    full_name='Nrmk.IndyFramework.Control.InverseKinematics',
    index=48,
    containing_service=None,
    input_type=control__msgs__pb2._INVERSEKINEMATICSREQ,
    output_type=control__msgs__pb2._INVERSEKINEMATICSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckAproachRetractValid',
    full_name='Nrmk.IndyFramework.Control.CheckAproachRetractValid',
    index=49,
    containing_service=None,
    input_type=control__msgs__pb2._CHECKAPROACHRETRACTVALIDREQ,
    output_type=control__msgs__pb2._CHECKAPROACHRETRACTVALIDRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPalletPointList',
    full_name='Nrmk.IndyFramework.Control.GetPalletPointList',
    index=50,
    containing_service=None,
    input_type=control__msgs__pb2._GETPALLETPOINTLISTREQ,
    output_type=control__msgs__pb2._GETPALLETPOINTLISTRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CalculateRelativePose',
    full_name='Nrmk.IndyFramework.Control.CalculateRelativePose',
    index=51,
    containing_service=None,
    input_type=control__msgs__pb2._CALCULATERELATIVEPOSEREQ,
    output_type=control__msgs__pb2._CALCULATERELATIVEPOSERES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CalculateCurrentPoseRel',
    full_name='Nrmk.IndyFramework.Control.CalculateCurrentPoseRel',
    index=52,
    containing_service=None,
    input_type=control__msgs__pb2._CALCULATECURRENTPOSERELREQ,
    output_type=control__msgs__pb2._CALCULATECURRENTPOSERELRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PingFromConty',
    full_name='Nrmk.IndyFramework.Control.PingFromConty',
    index=53,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleOpDevice',
    full_name='Nrmk.IndyFramework.Control.GetTeleOpDevice',
    index=54,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TELEOPDEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleOpState',
    full_name='Nrmk.IndyFramework.Control.GetTeleOpState',
    index=55,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TELEOPSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectTeleOpDevice',
    full_name='Nrmk.IndyFramework.Control.ConnectTeleOpDevice',
    index=56,
    containing_service=None,
    input_type=control__msgs__pb2._TELEOPDEVICE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisConnectTeleOpDevice',
    full_name='Nrmk.IndyFramework.Control.DisConnectTeleOpDevice',
    index=57,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadTeleOpInput',
    full_name='Nrmk.IndyFramework.Control.ReadTeleOpInput',
    index=58,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TELEP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartTeleOp',
    full_name='Nrmk.IndyFramework.Control.StartTeleOp',
    index=59,
    containing_service=None,
    input_type=control__msgs__pb2._TELEOPSTATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopTeleOp',
    full_name='Nrmk.IndyFramework.Control.StopTeleOp',
    index=60,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPlayRate',
    full_name='Nrmk.IndyFramework.Control.SetPlayRate',
    index=61,
    containing_service=None,
    input_type=control__msgs__pb2._TELEPLAYRATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlayRate',
    full_name='Nrmk.IndyFramework.Control.GetPlayRate',
    index=62,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TELEPLAYRATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleFileList',
    full_name='Nrmk.IndyFramework.Control.GetTeleFileList',
    index=63,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=control__msgs__pb2._TELEOPFILELIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveTeleMotion',
    full_name='Nrmk.IndyFramework.Control.SaveTeleMotion',
    index=64,
    containing_service=None,
    input_type=control__msgs__pb2._TELEFILEREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadTeleMotion',
    full_name='Nrmk.IndyFramework.Control.LoadTeleMotion',
    index=65,
    containing_service=None,
    input_type=control__msgs__pb2._TELEFILEREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTeleMotion',
    full_name='Nrmk.IndyFramework.Control.DeleteTeleMotion',
    index=66,
    containing_service=None,
    input_type=control__msgs__pb2._TELEFILEREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableTeleKey',
    full_name='Nrmk.IndyFramework.Control.EnableTeleKey',
    index=67,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveTeleJ',
    full_name='Nrmk.IndyFramework.Control.MoveTeleJ',
    index=68,
    containing_service=None,
    input_type=control__msgs__pb2._MOVETELEJREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveTeleL',
    full_name='Nrmk.IndyFramework.Control.MoveTeleL',
    index=69,
    containing_service=None,
    input_type=control__msgs__pb2._MOVETELELREQ,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveFL',
    full_name='Nrmk.IndyFramework.Control.MoveFL',
    index=70,
    containing_service=None,
    input_type=control__msgs__pb2._MOVEFLREQ,
    output_type=control__msgs__pb2._MOVEFLRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTROL)

DESCRIPTOR.services_by_name['Control'] = _CONTROL

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethercat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ethercat_msgs_pb2 as ethercat__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ethercat.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x65thercat.proto\x12\x12Nrmk.IndyFramework\x1a\x13\x65thercat_msgs.proto\x1a\x11\x63ommon_msgs.proto2\xb2\x19\n\x08\x45therCAT\x12P\n\x0fGetMasterStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.MasterStatus\"\x00\x12N\n\x0eGetSlaveStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.SlaveStatus\"\x00\x12V\n\x11GetRxDomainStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EcatDomainStatus\"\x00\x12V\n\x11GetTxDomainStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EcatDomainStatus\"\x00\x12Q\n\rIsSystemReady\x12\x19.Nrmk.IndyFramework.Empty\x1a#.Nrmk.IndyFramework.EcatSystemReady\"\x00\x12I\n\tIsServoOn\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.EcatServoOn\"\x00\x12P\n\x0fGetSlaveTypeNum\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.SlaveTypeNum\"\x00\x12L\n\x12ResetOverflowCount\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12K\n\nSetServoRx\x12 .Nrmk.IndyFramework.ServoRxIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12K\n\nGetServoRx\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1b.Nrmk.IndyFramework.ServoRx\"\x00\x12K\n\nGetServoTx\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1b.Nrmk.IndyFramework.ServoTx\"\x00\x12S\n\x0eSetServoRxKeba\x12$.Nrmk.IndyFramework.ServoRxIndexKeba\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12S\n\x0eGetServoRxKeba\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1f.Nrmk.IndyFramework.ServoRxKeba\"\x00\x12S\n\x0eGetServoTxKeba\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1f.Nrmk.IndyFramework.ServoTxKeba\"\x00\x12I\n\nSetServoOn\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0bSetServoOff\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12V\n\x13GetServoTemperature\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1d.Nrmk.IndyFramework.ServoTemp\"\x00\x12U\n\x11GetServoErrorCode\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1e.Nrmk.IndyFramework.ServoError\"\x00\x12I\n\nResetServo\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Q\n\x12SetCOREManualBrake\x12\x1e.Nrmk.IndyFramework.ServoBrake\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cSetEndtoolRx\x12\x1d.Nrmk.IndyFramework.EndtoolRx\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cGetEndtoolRx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.EndtoolRx\"\x00\x12J\n\x0cGetEndtoolTx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.EndtoolTx\"\x00\x12X\n\x13GetEndtoolDockingTx\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EndtoolDockingTx\"\x00\x12J\n\x0cSetIOBoardRx\x12\x1d.Nrmk.IndyFramework.IOBoardRx\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cGetIOBoardTx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.IOBoardTx\"\x00\x12J\n\x0cGetIOBoardRx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.IOBoardRx\"\x00\x12L\n\x05GetDI\x12\x1c.Nrmk.IndyFramework.DIOIndex\x1a#.Nrmk.IndyFramework.DIODigitalInput\"\x00\x12M\n\x05GetDO\x12\x1c.Nrmk.IndyFramework.DIOIndex\x1a$.Nrmk.IndyFramework.DIODigitalOutput\"\x00\x12J\n\x05SetDO\x12$.Nrmk.IndyFramework.DIODigitalOutput\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Q\n\x0fGetMaxTorqueSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileVelSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileAccSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileDecSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12N\n\x0fSetMaxTorqueSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileVelSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileAccSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileDecSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Y\n\x11GetRobotZeroCount\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\".Nrmk.IndyFramework.RobotZeroCount\"\x00\x12T\n\x15SetRobotZeroAsCurrent\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[ethercat__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_ETHERCAT = _descriptor.ServiceDescriptor(
  name='EtherCAT',
  full_name='Nrmk.IndyFramework.EtherCAT',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=79,
  serialized_end=3329,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMasterStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetMasterStatus',
    index=0,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._MASTERSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetSlaveStatus',
    index=1,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._SLAVESTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRxDomainStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetRxDomainStatus',
    index=2,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATDOMAINSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxDomainStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetTxDomainStatus',
    index=3,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATDOMAINSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsSystemReady',
    full_name='Nrmk.IndyFramework.EtherCAT.IsSystemReady',
    index=4,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATSYSTEMREADY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsServoOn',
    full_name='Nrmk.IndyFramework.EtherCAT.IsServoOn',
    index=5,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATSERVOON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveTypeNum',
    full_name='Nrmk.IndyFramework.EtherCAT.GetSlaveTypeNum',
    index=6,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._SLAVETYPENUM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetOverflowCount',
    full_name='Nrmk.IndyFramework.EtherCAT.ResetOverflowCount',
    index=7,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoRx',
    index=8,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVORXINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoRx',
    index=9,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVORX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTx',
    index=10,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoRxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoRxKeba',
    index=11,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVORXINDEXKEBA,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoRxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoRxKeba',
    index=12,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVORXKEBA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTxKeba',
    index=13,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTXKEBA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoOn',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoOn',
    index=14,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoOff',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoOff',
    index=15,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTemperature',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTemperature',
    index=16,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTEMP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoErrorCode',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoErrorCode',
    index=17,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOERROR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetServo',
    full_name='Nrmk.IndyFramework.EtherCAT.ResetServo',
    index=18,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCOREManualBrake',
    full_name='Nrmk.IndyFramework.EtherCAT.SetCOREManualBrake',
    index=19,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOBRAKE,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndtoolRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetEndtoolRx',
    index=20,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ENDTOOLRX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolRx',
    index=21,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLRX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolTx',
    index=22,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolDockingTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolDockingTx',
    index=23,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLDOCKINGTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetIOBoardRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetIOBoardRx',
    index=24,
    containing_service=None,
    input_type=ethercat__msgs__pb2._IOBOARDRX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIOBoardTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetIOBoardTx',
    index=25,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._IOBOARDTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIOBoardRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetIOBoardRx',
    index=26,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._IOBOARDRX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDI',
    full_name='Nrmk.IndyFramework.EtherCAT.GetDI',
    index=27,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIOINDEX,
    output_type=ethercat__msgs__pb2._DIODIGITALINPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetDO',
    index=28,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIOINDEX,
    output_type=ethercat__msgs__pb2._DIODIGITALOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetDO',
    index=29,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIODIGITALOUTPUT,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaxTorqueSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetMaxTorqueSDO',
    index=30,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileVelSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileVelSDO',
    index=31,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileAccSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileAccSDO',
    index=32,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileDecSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileDecSDO',
    index=33,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetMaxTorqueSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetMaxTorqueSDO',
    index=34,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileVelSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileVelSDO',
    index=35,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileAccSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileAccSDO',
    index=36,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileDecSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileDecSDO',
    index=37,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotZeroCount',
    full_name='Nrmk.IndyFramework.EtherCAT.GetRobotZeroCount',
    index=38,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._ROBOTZEROCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotZeroAsCurrent',
    full_name='Nrmk.IndyFramework.EtherCAT.SetRobotZeroAsCurrent',
    index=39,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ETHERCAT)

DESCRIPTOR.services_by_name['EtherCAT'] = _ETHERCAT

# @@protoc_insertion_point(module_scope)
